from setuptools import setup, find_packages
setup(
    name='qz',
    version='2',
    description='Print "Hello, World!"',
    url='https://github.com/donno2048/qz',
    packages=find_packages(),
    license='MIT',
    author='Elisha Hollander'
)
